Pattern

Trait Pattern 

pub trait Pattern: Sealed { }
Available on crate feature alloc only.
A stable pattern type that can be used by replace_cow and replacen_cow.

This trait is local to this crate because the standard library Pattern trait is still unstable to name in public APIs.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl Pattern for &&str

Source

impl Pattern for &[char]

Source

impl Pattern for &str

Source

impl Pattern for char

Source

impl<const N: usize> Pattern for &[char; N]

Source

impl<const N: usize> Pattern for [char; N]

Implementors

Source

impl<F> Pattern for F
where F: FnMut(char) -> bool,