pub trait StartsWithIgnoreAsciiCase {
// Required methods
fn starts_with_ignore_ascii_case<S: AsRef<[u8]>>(&self, b: S) -> bool;
fn starts_with_ignore_ascii_case_with_lowercase<S: AsRef<[u8]>>(
&self,
b: S,
) -> bool;
fn starts_with_ignore_ascii_case_with_uppercase<S: AsRef<[u8]>>(
&self,
b: S,
) -> bool;
}Expand description
To extend [u8] and str to have starts_with_ignore_ascii_case, starts_with_ignore_ascii_case_with_lowercase and starts_with_ignore_ascii_case_with_uppercase methods.
Required Methods
Sourcefn starts_with_ignore_ascii_case<S: AsRef<[u8]>>(&self, b: S) -> bool
fn starts_with_ignore_ascii_case<S: AsRef<[u8]>>(&self, b: S) -> bool
Returns true if the given string slice case-insensitively (only ignoring ASCII case) matches a prefix of this string slice.
Sourcefn starts_with_ignore_ascii_case_with_lowercase<S: AsRef<[u8]>>(
&self,
b: S,
) -> bool
fn starts_with_ignore_ascii_case_with_lowercase<S: AsRef<[u8]>>( &self, b: S, ) -> bool
Returns true if the given lowercase string slice case-insensitively (only ignoring ASCII case) matches a prefix of this string slice.
Sourcefn starts_with_ignore_ascii_case_with_uppercase<S: AsRef<[u8]>>(
&self,
b: S,
) -> bool
fn starts_with_ignore_ascii_case_with_uppercase<S: AsRef<[u8]>>( &self, b: S, ) -> bool
Returns true if the given uppercase string slice case-insensitively (only ignoring ASCII case) matches a prefix of this string slice.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".